Package: httpcode
Title: 'HTTP' Status Code Helper
Description: Find and explain the meaning of 'HTTP' status codes.
    Functions included for searching for codes by full or partial number,
    by message, and get appropriate dog and cat images for many
    status codes.
Version: 0.3.0
Authors@R: person("Scott", "Chamberlain", role = c("aut","cre"),
    email = "myrmecocystus@gmail.com", 
    comment = c(ORCID = "0000-0003-1444-9135"))
License: MIT + file LICENSE
URL: https://github.com/sckott/httpcode
BugReports: https://github.com/sckott/httpcode/issues
Encoding: UTF-8
Language: en-US
Suggests: testthat
RoxygenNote: 7.1.0
NeedsCompilation: no
Packaged: 2020-04-10 03:18:28 UTC; sckott
Author: Scott Chamberlain [aut, cre] (<https://orcid.org/0000-0003-1444-9135>)
Maintainer: Scott Chamberlain <myrmecocystus@gmail.com>
Repository: CRAN
Date/Publication: 2020-04-10 06:20:02 UTC
