% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/httpcode-package.R
\docType{package}
\name{httpcode-package}
\alias{httpcode-package}
\alias{httpcode}
\title{httpcode}
\description{
Explain the meaning of HTTP status codes
}
\author{
Scott Chamberlain \email{myrmecocystus@gmail.com}
}
\keyword{package}
